@@ -1,12 +1,4 @@
-# check delete_MAR_censoring ------------------------------
-test_that("delete_MAR_censoring() calls check_delete_args_MAR()", {
-  expect_error(
-    delete_MAR_censoring(df_XY_100, 0.1, 1, cols_ctrl = 3),
-    "indices in cols_ctrl must be in 1:ncol\\(ds)"
-  )
-})
-
-test_that("delete_MAR_censoring() and delete_cutoff(), which is called by
+test_that("delete_MAR_censoring() and delete_censoring(), which is called by
           delete_MAR_censoring(), work", {
   set.seed(12345)
 
@@ -139,15 +131,52 @@ test_that("delete_MAR_censoring() (and delete_censoring(), which is called by
   expect_equal(count_NA(tbl_mis[1:20, ]), c(X = 10, Y = 20, Z = 0))
 })
 
+test_that("delete_censoring() works with n_mis_stochastic = TRUE and sorting", {
+  N <- 1000
+  set.seed(12345)
+
+  # where = "lower"
+  dfs_mis <- replicate(
+    N,
+    delete_MNAR_censoring(matrix(1:5, ncol = 1), 0.42, 1,
+      n_mis_stochastic = TRUE, where = "lower"
+    )
+  )
+  expect_true(all(is.na(dfs_mis[1:2, , ])))
+  expect_false(anyNA(dfs_mis[4:5, , ]))
+  n_mis <- sum(is.na(dfs_mis[3, , ]))
+  expect_true(stats::qbinom(1e-10, N, 0.42 * 5 - 2) <= n_mis)
+  expect_true(n_mis <= stats::qbinom(1e-10, N, 0.42 * 5 - 2, FALSE))
+
+  # where = "upper"
+  dfs_mis <- replicate(
+    N,
+    delete_MNAR_censoring(matrix(1:5, ncol = 1), 0.42, 1,
+      n_mis_stochastic = TRUE, where = "upper"
+    )
+  )
+  expect_true(all(is.na(dfs_mis[4:5, , ])))
+  expect_false(anyNA(dfs_mis[1:2, , ]))
+  n_mis <- sum(is.na(dfs_mis[3, , ]))
+  expect_true(stats::qbinom(1e-10, N, 0.42 * 5 - 2) <= n_mis)
+  expect_true(n_mis <= stats::qbinom(1e-10, N, 0.42 * 5 - 2, FALSE))
+
+  # where = "both"
+  dfs_mis <- replicate(
+    N,
+    delete_MNAR_censoring(matrix(1:5, ncol = 1), 0.42, 1,
+      n_mis_stochastic = TRUE, where = "both"
+    )
+  )
+  expect_true(all(is.na(dfs_mis[c(1, 5), , ])))
+  expect_false(anyNA(dfs_mis[3:4, , ]))
+  n_mis <- sum(is.na(dfs_mis[2, , ]))
+  expect_true(stats::qbinom(1e-10, N, 0.42 * 5 - 2) <= n_mis)
+  expect_true(n_mis <= stats::qbinom(1e-10, N, 0.42 * 5 - 2, FALSE))
+})
+
 # check delete_MNAR_censoring -----------------------------
 test_that("delete_MNAR_censoring() works", {
-
-  # check that delete_MNAR_censoring() calls check_delete_args_MNAR()
-  expect_error(
-    delete_MNAR_censoring(df_XY_X_mis, 0.1, "X"),
-    "cols_mis must be completely observed; no NAs in ds\\[, cols_mis\\] allowed"
-  )
-
   df_mis <- delete_MNAR_censoring(df_XY_100, c(0.3, 0.1), c("X", "Y"))
   expect_equal(count_NA(df_mis), c(X = 30, Y = 10))
   expect_true(all(is.na(df_mis[1:30, "X"])))
