@@ -1,18 +1,11 @@
-test_that("delete_MAR_one_group() calls check_delete_args_MAR()", {
-  expect_error(
-    delete_MAR_one_group(df_XY_100, 0.1, 1, cols_ctrl = 3),
-    "indices in cols_ctrl must be in 1:ncol\\(ds)"
-  )
-})
-
 test_that("delete_one_group() and delete_MAR_one_group() works", {
   set.seed(12345)
 
-  # check p too low to get missing values with stochastic = FALSE -----
+  # check p too low to get missing values with n_mis_stochastic = FALSE -----
   expect_equal(
     count_NA(delete_MAR_one_group(df_XY_100, 0.001,
       cols_mis = "Y", cols_ctrl = "X",
-      stochastic = FALSE
+      n_mis_stochastic = FALSE
     )),
     c(X = 0, Y = 0)
   )
@@ -38,18 +31,10 @@ test_that("delete_one_group() and delete_MAR_one_group() works", {
       isTRUE(all.equal(count_NA(df_mis[1:50, ]), c(X = 0, Y = 0, Z = 0)))
   )
 
-  # to high p
-  expect_warning(
-    df_mis <- delete_MAR_one_group(df_XYZ_100, 0.9, "X", "Y"),
-    "not enough objects in miss_group in column Y to reach p"
-  )
-  expect_equal(count_NA(df_mis), c(X = 50, Y = 0, Z = 0))
-
-
-  # check FUN ---------------------------------------------
+  # check cutoff_fun ---------------------------------------------
   # median via stats::quantile()
   df_mis <- delete_MAR_one_group(df_XYZ_100, 0.2, "X", "Y",
-    FUN = stats::quantile,
+    cutoff_fun = stats::quantile,
     probs = 0.5
   )
   expect_equal(count_NA(df_mis), c(X = 20, Y = 0, Z = 0))
@@ -60,7 +45,7 @@ test_that("delete_one_group() and delete_MAR_one_group() works", {
 
   # unequal groups via stats::quantile()
   df_mis <- delete_MAR_one_group(df_XYZ_100, 0.2, "X", "Y",
-    FUN = stats::quantile,
+    cutoff_fun = stats::quantile,
     probs = 0.2
   )
   expect_equal(count_NA(df_mis), c(X = 20, Y = 0, Z = 0))
@@ -69,7 +54,7 @@ test_that("delete_one_group() and delete_MAR_one_group() works", {
       isTRUE(all.equal(count_NA(df_mis[21:100, ]), c(X = 20, Y = 0, Z = 0)))
   )
 
-  # check unorderd factor as ctrl_col and prob ------------
+  # check unorderd factor as ctrl_col and prop ------------
   df_mis <- delete_MAR_one_group(df_with_unord_factor, 0.4, "Y", "X")
   expect_equal(count_NA(df_mis), c(X = 0, Y = 8))
   expect_true(
@@ -78,16 +63,16 @@ test_that("delete_one_group() and delete_MAR_one_group() works", {
   )
 
   df_mis <- delete_MAR_one_group(df_with_unord_factor, 0.4, "Y", "X",
-    prob = 0.4
+    prop = 0.4
   )
   expect_equal(count_NA(df_mis), c(X = 0, Y = 8))
   expect_true(isTRUE(all.equal(count_NA(df_mis[1:8, ]), c(X = 0, Y = 8))) ||
     isTRUE(all.equal(count_NA(df_mis[9:20, ]), c(X = 0, Y = 8))))
 
 
-  # check stochastic = TRUE -------------------------------
+  # check n_mis_stochastic = TRUE -------------------------------
   expect_false(anyNA(delete_MAR_one_group(df_XYZ_100, 0, "X", "Y",
-    stochastic = TRUE
+    n_mis_stochastic = TRUE
   )))
 
   N <- 1000
@@ -95,7 +80,7 @@ test_that("delete_one_group() and delete_MAR_one_group() works", {
   colnames(res) <- c("X1", "X2", "Y")
   for (i in seq_len(N)) {
     ds_mis <- delete_MAR_one_group(df_XY_100, 0.2, "X", "Y",
-      stochastic = TRUE
+      n_mis_stochastic = TRUE
     )
     res[i, "Y"] <- sum(is.na(ds_mis[, "Y"]))
     res[i, "X1"] <- sum(is.na(ds_mis[1:50, "X"]))
@@ -151,6 +136,16 @@ test_that("delete_one_group() and delete_MAR_one_group() works", {
   #              c(X = 0, Y = 4))
 })
 
+test_that("delete_one_group() works with high p", {
+  old <- options("missMethods.warn.too.high.p" = TRUE)
+  df_mis <- expect_warning(
+    delete_MAR_one_group(df_XY_20, 0.7, "X", "Y"),
+    "p = 0.7 is too high for the chosen mechanims \\(and data);it will be reduced to 0.5"
+  )
+  expect_equal(count_NA(df_mis), c(X = 10, Y = 0))
+  options(old)
+})
+
 test_that("delete_MAR_one_group() (and delete_one_group(), which is called by
           delete_MAR_one_group()) works for matrices", {
   set.seed(12345)
@@ -181,12 +176,6 @@ test_that("delete_MAR_one_group() (and delete_one_group(), which is called by
 
 # check delete_MNAR_one_group -----------------------------
 test_that("delete_MNAR_one_group() works", {
-  # check that delete_MNAR_one_group() calls check_delete_args_MNAR()
-  expect_error(
-    delete_MNAR_one_group(df_XY_X_mis, 0.1, "X"),
-    "cols_mis must be completely observed; no NAs in ds\\[, cols_mis\\] allowed"
-  )
-
   df_mis <- delete_MNAR_one_group(df_XY_100, c(0.3, 0.1), c("X", "Y"))
   expect_equal(count_NA(df_mis), c(X = 30, Y = 10))
 })
